package org.jboss.security.plugins;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.security.AccessController;
import java.security.Principal;
import java.security.PrivilegedAction;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;
import javax.security.auth.Subject;
import javax.security.auth.callback.CallbackHandler;
import javax.security.auth.login.LoginContext;
import javax.security.auth.login.LoginException;

class SubjectActions {
  static Subject getActiveSubject() {
    Subject subject = AccessController.<Subject>doPrivileged(GetSubjectAction.ACTION);
    return subject;
  }
  
  static void copySubject(Subject fromSubject, Subject toSubject) {
    copySubject(fromSubject, toSubject, false);
  }
  
  static void copySubject(Subject fromSubject, Subject toSubject, boolean setReadOnly) {
    CopySubjectAction action = new CopySubjectAction(fromSubject, toSubject, setReadOnly);
    if (System.getSecurityManager() != null) {
      AccessController.doPrivileged((PrivilegedAction)action);
    } else {
      action.run();
    } 
  }
  
  static LoginContext createLoginContext(String securityDomain, Subject subject, CallbackHandler handler) throws LoginException {
    LoginContextAction action = new LoginContextAction(securityDomain, subject, handler);
    try {
      LoginContext lc = AccessController.<LoginContext>doPrivileged((PrivilegedExceptionAction)action);
      return lc;
    } catch (PrivilegedActionException e) {
      Exception ex = e.getException();
      if (ex instanceof LoginException)
        throw (LoginException)ex; 
      throw new LoginException(ex.getMessage());
    } 
  }
  
  static ClassLoader getContextClassLoader() {
    ClassLoader loader = AccessController.<ClassLoader>doPrivileged(GetTCLAction.ACTION);
    return loader;
  }
  
  static Object setContextInfo(Object key, Object value) {
    SetContextInfoAction action = new SetContextInfoAction(key, value);
    Object prevInfo = AccessController.doPrivileged((PrivilegedAction)action);
    return prevInfo;
  }
  
  static void pushSubjectContext(Principal principal, Object credential, Subject subject) {
    if (System.getSecurityManager() == null) {
      PrincipalInfoAction.NON_PRIVILEGED.push(principal, credential, subject);
    } else {
      PrincipalInfoAction.PRIVILEGED.push(principal, credential, subject);
    } 
  }
  
  static void popSubjectContext() {
    if (System.getSecurityManager() == null) {
      PrincipalInfoAction.NON_PRIVILEGED.pop();
    } else {
      PrincipalInfoAction.PRIVILEGED.pop();
    } 
  }
  
  static String toString(Subject subject) {
    ToStringSubjectAction action = new ToStringSubjectAction(subject);
    String info = AccessController.<String>doPrivileged((PrivilegedAction)action);
    return info;
  }
}
